@@ -406,7 +406,23 @@ class DataStore(QtCore.QObject):
 
         logger.debug("REQUEST: {} {}".format(trend, start_end))
 
+        assert trend in self.TREND_TYPES
         self.last_trend = trend
+        start, end = start_end
+        assert end > start
+
+        # FIXME: we really need to do something to put a check on the
+        # length of the request.  It really should be based on the
+        # bytes being requested, but we don't know the sample rate a
+        # priori.
+        span = abs(end - start)
+        max_seconds = const.TREND_MAX_SECONDS[trend]
+        if span > max_seconds:
+            self.signal_data_retrieve_done.emit((
+                f"Requested span too large: {max_seconds} seconds max for {trend} trend",
+                self.active
+            ))
+            return
 
         if self.online:
             if trend == 'min':
@@ -420,14 +436,14 @@ class DataStore(QtCore.QObject):
             elif trend != self.online:
                 self.online_restart()
                 return
-
-        now = gpsnow()
-        start, end = start_end
+            # note we continue if online and trend is not changing
 
         # expand range to ints
         rstart = int(start)
         rend = int(np.ceil(end))
 
+        now = gpsnow()
+
         if rstart > now:
             # self.signal_data_retrieve_done.emit("Requested start time in the future.")
             return
