@@ -7,12 +7,14 @@ import numpy as np
 
 import pyqtgraph as pg
 try:
-    from qtpy import QtGui, QtWidgets, QtCore
+    from qtpy import QtGui, QtWidgets
+    from qtpy.QtCore import Qt, QRegularExpression, QTimer
     from qtpy.QtWidgets import QStyle, QFileDialog, QFontDialog
     from qtpy.QtGui import QFont, QColor
     from qtpy import uic
 except ImportError:
-    from PyQt5 import QtGui, QtWidgets, QtCore
+    from PyQt5 import QtGui, QtWidgets
+    from PyQt5.QtCore import Qt, QRegularExpression, QTimer
     from PyQt5.QtWidgets import QStyle, QFileDialog, QFontDialog
     from PyQt5.QtGui import QFont, QColor
     from PyQt5 import uic
@@ -125,7 +127,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         # window/range entry
 
         def NonEmptyValidator():
-            return QtGui.QRegularExpressionValidator(QtCore.QRegularExpression('.+'))
+            return QtGui.QRegularExpressionValidator(QRegularExpression('.+'))
 
         self.entryT0GPS.textEdited.connect(self.update_entryT0Greg)
         self.entryT0GPS.setValidator(QtGui.QDoubleValidator())
@@ -349,12 +351,12 @@ class NDScope(QMainWindow, Ui_MainWindow):
             self.graphView.setBackground(QColor('white'))
             self.referenceTimeLabel.setAttr('color', QColor('black'))
             self.referenceTimeLabel.setText(self.referenceTimeLabel.text)
-            self.backgroundCheckBox.setCheckState(QtCore.Qt.Checked)
+            self.backgroundCheckBox.setCheckState(Qt.Checked)
         elif color == 'k':
             self.graphView.setBackground(QColor('black'))
             self.referenceTimeLabel.setAttr('color', QColor('white'))
             self.referenceTimeLabel.setText(self.referenceTimeLabel.text)
-            self.backgroundCheckBox.setCheckState(QtCore.Qt.Unchecked)
+            self.backgroundCheckBox.setCheckState(Qt.Unchecked)
         else:
             raise ValueError("background color value must be 'w' or 'k'.")
 
@@ -609,7 +611,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         self.data.request(trend, (start, end))
 
     def _fetch(self, **kwargs):
-        if QtGui.QApplication.keyboardModifiers() == QtCore.Qt.ShiftModifier:
+        if QtGui.QApplication.keyboardModifiers() == Qt.ShiftModifier:
             self.data.reset()
         if 't0' in kwargs:
             t0 = kwargs['t0']
@@ -1048,7 +1050,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         """connect the crosshair update signal handler"""
         self._crosshair_proxy = pg.SignalProxy(
             self.graphView.scene().sigMouseMoved,
-            rateLimit=60,
+            rateLimit=20,
             slot=self._update_crosshair)
 
     def _enable_crosshair(self):
@@ -1057,6 +1059,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
             plot.disableAutoRange(axis='y')
         self._connect_crosshair()
         self.graphView.scene().sigMouseClicked.connect(self._clicked_crosshair)
+        self.graphView.setCursor(Qt.CrossCursor)
         logger.info("crosshair enabled")
 
     def enable_crosshair(self):
@@ -1074,6 +1077,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
             self.graphView.scene().sigMouseClicked.disconnect(self._clicked_crosshair)
         except TypeError:
             pass
+        self.graphView.setCursor(Qt.ArrowCursor)
         self.crosshairGPS.setText('')
         self.crosshairGreg.setText('')
         self.crosshairYValue.setText('')
@@ -1173,7 +1177,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
             self.set_font(font)
 
     def _background_select(self, state):
-        if state == QtCore.Qt.Checked:
+        if state == Qt.Checked:
             self.set_background('w')
         else:
             self.set_background('k')
@@ -1214,7 +1218,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
             return
         self.status_message(f"Writing file {path}...", timeout=10)
         self.exportPath.setText(path)
-        QtCore.QTimer.singleShot(1, self._export)
+        QTimer.singleShot(1, self._export)
         # we do this timer thing so that the event loop will display
         # the above status message, in case it takes some time to
         # render/construct the output
@@ -1254,7 +1258,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
                 path,
             )
             kwargs = dict(
-                bw=(self.backgroundCheckBox.checkState() == QtCore.Qt.Checked),
+                bw=(self.backgroundCheckBox.checkState() == Qt.Checked),
                 window_title=self.windowTitle().replace('ndscope: ', ''),
                 time_window=self.get_window(),
                 font_size=self.font.pointSize(),
